@@ -1,14 +1,16 @@
 package TableData::Test::Source::Iterator;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-01'; # DATE
-our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.009'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
+
 use Role::Tiny::With;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-26'; # DATE
+our $DIST = 'TableDataRoles-Standard'; # DIST
+our $VERSION = '0.010'; # VERSION
+
 with 'TableDataRole::Source::Iterator';
 
 sub new {
@@ -21,7 +23,7 @@ sub new {
             my $i = 0;
             sub {
                 $i++;
-                return undef if $i > $args{num_rows};
+                return undef if $i > $args{num_rows}; ## no critic: Subroutines::ProhibitExplicitReturnUndef
                 return {i=>$args{random} ? int(rand()*$args{num_rows} + 1) : $i};
             };
         },
@@ -43,7 +45,7 @@ TableData::Test::Source::Iterator - A test table
 
 =head1 VERSION
 
-This document describes version 0.009 of TableData::Test::Source::Iterator (from Perl distribution TableDataRoles-Standard), released on 2021-06-01.
+This document describes version 0.010 of TableData::Test::Source::Iterator (from Perl distribution TableDataRoles-Standard), released on 2021-09-26.
 
 =head1 SYNOPSIS
 
@@ -86,6 +88,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/TableDataR
 
 Source repository is at L<https://github.com/perlancar/perl-TableDataRoles-Standard>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataRoles-Standard>
@@ -94,15 +124,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
