@@ -1,13 +1,16 @@
 package TableDataRole::Source::Iterator;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-01'; # DATE
-our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.009'; # VERSION
-
 use 5.010001;
+use strict;
+use warnings;
+
 use Role::Tiny;
-use Role::Tiny::With;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-26'; # DATE
+our $DIST = 'TableDataRoles-Standard'; # DIST
+our $VERSION = '0.010'; # VERSION
+
 with 'TableDataRole::Spec::Basic';
 
 sub _new {
@@ -36,14 +39,14 @@ sub _get_row {
     if ($self->{buffer}) {
         my $row = delete $self->{buffer};
         if (!ref($row) && $row == -1) {
-            return undef;
+            return undef; ## no critic: Subroutines::ProhibitExplicitReturnUndef
         } else {
             return $row;
         }
     } else {
         $self->reset_iterator unless $self->{iterator};
         my $row = $self->{iterator}->();
-        return undef unless $row;
+        return undef unless $row; ## no critic: Subroutines::ProhibitExplicitReturnUndef
         return $row;
     }
 }
@@ -57,7 +60,7 @@ sub _peek_row {
         $self->{buffer} = $self->{iterator}->() // -1;
     }
     if (!ref($self->{buffer}) && $self->{buffer} == -1) {
-        return undef;
+        return undef; ## no critic: Subroutines::ProhibitExplicitReturnUndef
     } else {
         return $self->{buffer};
     }
@@ -153,7 +156,7 @@ TableDataRole::Source::Iterator - Get table data from an iterator
 
 =head1 VERSION
 
-This document describes version 0.009 of TableDataRole::Source::Iterator (from Perl distribution TableDataRoles-Standard), released on 2021-06-01.
+This document describes version 0.010 of TableDataRole::Source::Iterator (from Perl distribution TableDataRoles-Standard), released on 2021-09-26.
 
 =head1 SYNOPSIS
 
@@ -211,14 +214,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/TableDataR
 
 Source repository is at L<https://github.com/perlancar/perl-TableDataRoles-Standard>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataRoles-Standard>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<TableData>
@@ -227,11 +222,36 @@ L<TableData>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar@cpan.org.
+This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataRoles-Standard>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
