@@ -1,12 +1,16 @@
 package TableDataRole::Util::CSV;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-01'; # DATE
-our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.009'; # VERSION
-
 use 5.010001;
+use strict;
+use warnings;
+
 use Role::Tiny;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-26'; # DATE
+our $DIST = 'TableDataRoles-Standard'; # DIST
+our $VERSION = '0.010'; # VERSION
+
 requires 'get_column_names';
 requires 'has_next_item';
 requires 'get_next_item';
@@ -47,7 +51,7 @@ TableDataRole::Util::CSV - Provide as_csv() and other CSV-related methods
 
 =head1 VERSION
 
-This document describes version 0.009 of TableDataRole::Util::CSV (from Perl distribution TableDataRoles-Standard), released on 2021-06-01.
+This document describes version 0.010 of TableDataRole::Util::CSV (from Perl distribution TableDataRoles-Standard), released on 2021-09-26.
 
 =head1 PROVIDED METHODS
 
@@ -61,6 +65,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/TableDataR
 
 Source repository is at L<https://github.com/perlancar/perl-TableDataRoles-Standard>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataRoles-Standard>
@@ -69,15 +101,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
